;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "shell-maker" "20251014.1155"
  "Interaction mode for making comint shells."
  '((emacs "27.1"))
  :url "https://github.com/xenodium/shell-maker"
  :commit "9388492f6cb56e52a56fbdf6d5fe68c1cdff4909"
  :revdesc "9388492f6cb5")
